function h = latext(xpos,ypos,string,align,ptsize,fontname)

% function h = latext(xpos,ypos,string,align,ptsize,fontname)
%
% Plot the LaTeX-style text string on a figure, in ptsize point size
% and aligned to top/bottom, left/right or centre (default).
% e.g. align = 'tl' for top left, 'r' for centre right, ' ' for centre.
% sub/superscripts are preceded by '_' or '^'.
% Note V_{max} must be written V_m_a_x.
% Greek letters / symbols are '\' followed by the equivalent
% letter in the symbol set; e.g. '\a' gives alpha.
% Similarly for math mode (italic) using '$'.
% Note: \f=phi, \h=eta, \j=varphi, \q=theta, \v=varpi, \y=psi.
% 
% Multiple effects must be in the order: _ or ^, $, \
%
% \\ produces new-line for multi-line text.
%
% The figure dimensions are adjusted to be the same as those
% used by 'print -deps' so that the text is the correct size relative
% to the graphics.
%
% fontname is the standard font used ('Symbol' is also used).
% fontname defaults to 'Times'.
%
% A vector of handles to the separate text items is returned.
%
% Nick Kingsbury, Cambridge University, Feb 2000

if nargin < 6, fontname = 'Times'; end
if nargin < 5, ptsize = 12; end
if nargin < 4, align = ' '; end

% Set figure dimensions.
% set(gcf,'position',[96    28   700   512]);
pos = [4    30   790   526]; % dimensions for figs under Win 95.
pos = [40    30   900   668];
if any(get(gcf,'position') ~= pos),
  set(gcf,'position',pos);
end

% Decode the string one symbol at a time and initially plot the result
% with its lower left at [xpos,ypos] to determine overall dimensions.
m = length(string);
h = [];
x = xpos;
y0 = ypos;
hgt = 0;
tothgt = 0;
small = round(ptsize * 0.75);
xmax = [];

row = [];
rowi = 1;
i = 1;
while i <= m,
  font = fontname;
  slant = 'normal';
  fs = ptsize;
  ch = string(i);
  y = y0;
  if string(i) == '_',   % Subscript
    y = y0 - 0.1*hgt;
    fs = small;
    i = i + 1;
    ch = string(i);
  elseif string(i) == '^',  % Subscript
    y = y0 + 0.4*hgt;
    fs = small;
    i = i + 1;
    ch = string(i);
  end
  if string(i) == '$',    % Math mode (italic)
    slant = 'italic';
    i = i + 1;
    ch = string(i);
  end
  if string(i) == '\',    % Greek / Symbol
    font = 'Symbol';
    i = i + 1;
    ch = string(i);
  end

  if ch == '\',           % New line
    xmax = [xmax; x];
    y0 = y0 - 1.1*hgt;
    x = xpos;
    rowi = rowi + 1;
    tothgt = tothgt + 1.1*hgt;
  else                    % Write next character.
    hh = text(x,y,ch);
    h = [h; hh];
    row = [row; rowi];
    set(hh,'FontName',font,'FontSize',fs,'FontAngle',slant,...
      'vert','bottom','horiz','left');
    ext = get(hh,'Extent');
    x = x + ext(3);
    if fs == ptsize, hgt = ext(4); end
  end

  i = i + 1;
end
xmax = [xmax; x];
tothgt = tothgt + hgt;

% Reposition text according to 'align'.
width = xmax - xpos;  % width is a vector of row widths.

dx = -0.5 * width;
dy = 0.5 * tothgt - hgt;

if length(findstr(align,'l')), dx = 0 * width; end
if length(findstr(align,'r')), dx = -width; end
if length(findstr(align,'t')), dy = -hgt; end
if length(findstr(align,'b')), dy = tothgt - hgt; end

for i = 1:size(h,1),
  xy = get(h(i),'position');
  xy(1) = xy(1) + dx(row(i));
  xy(2) = xy(2) + dy;
  set(h(i),'position',xy)
end

return
