% central_limit.m
% Demonstrate convergence of N pdfs to a Gaussian, for N=1:50.
% Three different input pdfs are used:
%   1. uniform
%   2. triangular with high skew
%   3. approx binary
%
% Nick Kingsbury, Cambridge University, August 2002.

pos1 = [0.05 0.2 0.9 0.6];

% Loop to select each of the desired input pdfs.
for pdfselect = 1:3,
   if pdfselect==1,      % uniform pdf 
      m = 50;
      pdfin = ones(m,1); 
      ymax=0.5;
      titl = '(a) Uniform pdf';
      tx = [1.8 0.25];
   elseif pdfselect==2,  % triangular pdf with high skew
      m = 50;
      pdfin = [1:m]'; 
      ymax=0.5;
      titl = '(b) Triangular pdf with high skew';
      tx = [1.5 0.35];
   elseif pdfselect==3,  % approx binary pdf
      m = 20;
      pdfin = [1;2;1;zeros(m-2,1);1;2;1]; 
      ymax=3; % approx binary pdf
      titl = '(c) Approximate binary pdf';
      tx = [1.1 2.25];
   end
   
   % Value of N for which the output will be plotted
   Nout = [1:4 6 8 10 12 15 20 30 50];
   
   % First plot a gaussian reference pdf.
   setfig(pdfselect)
   subplot('position',pos1);
   set(gca,'DefaultLineLineWidth',2);
   x = [-4:0.01:4]';
   pgauss = (1/sqrt(2*pi)) * exp(-x.*x/2);
   h=plot(x,pgauss,'r');
   set(h,'LineWidth',2);
   axis([-4 4 -0.1 ymax])
   grid on
   title('Gaussian pdf, sigma = 1','FontSize',14')
   pause
   
   % Initialise loop for each new value of N.
   pdfout = [0;1;0];
   h = [];
   for N = 1:max(Nout),
      pdfout = conv(pdfout,pdfin); % Convolve one more input pdf with the output pdf.
      pdfout = pdfout/sum(pdfout); % Normalise pdf to sum to unity.
      
      % Calculate correct range of x values for pdfout so it is zero mean and unit variance.
      x = [1:length(pdfout)]';
      x = x - sum(x.*pdfout);   % zero mean
      var = sum(x .* x .* pdfout);
      x = x / sqrt(var);        % unit variance
      
      % Plot a new curve for pdfout if N is in Nout.
      if ~isempty(find(Nout == N)),
         figure(pdfselect);
         if ~isempty(h)
            if N == 2,
               set(h,'LineWidth',2,'Color',[1 0 1]);    % Set first curve to magenta.
		         text(tx(1),tx(2),'N = 1','horiz','left','vert','mid','FontSize',14);
            else
               set(h,'LineWidth',1,'Color',[0 0.9 0]);    % Set previous curve to green.
            end
         end
         h=line(x,pdfout/(x(2)-x(1))); % Plot new curve in blue.
         set(h,'LineWidth',2,'Color',[0 0 1]);
         title([titl sprintf(', N = %d',N)],'FontSize',14);   % Show current N value on plot.
         pause
      end
      
   end
   
end

return

figure(1)
print -depsc '\1ngk\TEX\Probability\Figures\cen_lim1'

figure(2)
print -depsc '\1ngk\TEX\Probability\Figures\cen_lim2'

figure(3)
print -depsc '\1ngk\TEX\Probability\Figures\cen_lim3'

